<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="80px"
      class="l-mes"
      :disabled="!editable"
    >
      <el-row :gutter="10">
        <el-col :span="12">
          <el-form-item label="原零件号" prop="fromPartNo">
            <el-input
              v-model="dataForm.fromPartNo"
              placeholder="原零件号"
              readonly
            >
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openStockDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="新零件号" prop="toPartNo">
            <el-input
              v-model="dataForm.toPartNo"
              placeholder="新零件号"
              readonly
            >
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openNewStockDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="10">
        <el-col :span="12">
          <el-form-item label="原零件名称" prop="fromPartDesc">
            <el-input
              v-model="dataForm.fromPartDesc"
              placeholder="原零件名称"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="新零件名称" prop="toPartDesc">
            <el-input
              v-model="dataForm.toPartDesc"
              placeholder="新零件名称"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="10">
        <el-col :span="12">
          <el-form-item label="原批次号" prop="fromPartBatchNo">
            <el-input
              v-model="dataForm.fromPartBatchNo"
              placeholder="原批次号"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="新批次号" prop="toPartBatchNo">
            <el-input
              v-model="dataForm.toPartBatchNo"
              placeholder="新批次号"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="10">
        <el-col :span="12">
          <el-form-item label="从库位" prop="formLoc">
            <el-input
              v-model="dataForm.formLoc"
              placeholder="从库位"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="到库位" prop="toLoc">
            <el-input v-model="dataForm.toLoc" placeholder="到库位" readonly>
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openLocationDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="10">
        <el-col :span="12">
          <el-form-item label="调整数量" prop="adjNum">
            <el-input
              v-model="dataForm.adjNum"
              placeholder="调整数量"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="调整类型" prop="adjType">
            <el-select
              v-model="dataForm.adjType"
              placeholder="调整类型"
              filterable
              style="width: 100%"
            >
              <el-option
                v-for="item in adjTypeOption"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="10">
        <el-col :span="12">
          <el-form-item label="调整人" prop="adjUser">
            <el-input
              v-model="dataForm.adjUser"
              placeholder="调整人"
              readonly
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="原系统编号" prop="systemNo">
            <el-input
              v-model="dataForm.systemNo"
              placeholder="原系统号"
              readonly
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        v-if="editable"
        >确定</el-button
      >
    </span>
    <Stock :currshowlist.sync="showStock" @listenToPartEvent="selectStock" />
    <part-dialog
      :currshowlist.sync="showPart"
      @listenToPartEvent="selectPart"
    />
    <locationDialog
      :currshowlist.sync="showLocation"
      @listenToLocationEvent="selectLocation"
    />
  </el-dialog>
</template>

<script>
import PartDialog from '@/views/common/part'
import { getObj, addObj, putObj } from '@/api/warehouse/adjustdetail'
import { mapGetters } from 'vuex'
import Stock from '@/views/common/stock'
import { validateSixDecimalNotNull } from '../../../util/validate'
import locationDialog from '@/views/common/location.vue'
import Template from '../../quality/parts/template'
import { remote } from '../../../api/admin/dict'

export default {
  components: {
    Template,
    Stock,
    PartDialog,
    locationDialog
  },
  data() {
    return {
      adjTypeOption: [],
      showPart: false,
      showLocation: false,
      showStock: false,
      visible: false,
      dataForm: {
        id: 0,
        adjNo: '',
        fromPartNo: '',
        toPartNo: '',
        toLoc: '',
        fromPartBatchNo: '',
        toPartBatchNo: '',
        adjNum: '',
        adjTime: '',
        adjType: '',
        adjUser: '',
        toPartId: '',
        fromPartId: '',
        toLocId: '',
        fromLocId: '',
        status: '',
        systemNo: ''
      },
      dataRule: {
        fromPartNo: [
          { required: true, message: '原零件号不能为空', trigger: 'blur' }
        ],
        toPartNo: [
          { required: true, message: '新零件号不能为空', trigger: 'blur' }
        ],
        adjNum: [
          { required: true, message: '调整数量不能为空', trigger: 'blur' },
          { validator: validateSixDecimalNotNull, trigger: 'blur' }
        ],
        toLoc: [
          { required: true, message: '新库位号不能为空', trigger: 'blur' }
        ],
        toPartBatchNo: [
          { required: true, message: '新库位号不能为空', trigger: 'blur' }
        ],
        adjType: [
          { required: true, message: '调整类型不能为空', trigger: 'change' }
        ]
      },
      isSubmit: false
    }
  },
  created() {
    this.getAdjust()
  },
  computed: {
    ...mapGetters(['permissions', 'userInfo']),
    editable: function() {
      if (!this.dataForm.id) {
        return true
      }
      if (this.dataForm.id && this.dataForm.status == '未提交') {
        return true
      }
      return false
    }
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.dataForm.adjUser = this.userInfo.username
      this.dataForm.status = '未提交'
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    getAdjust() {
      remote('adjust_type').then((response) => {
        if (response.data.code === 0) {
          this.adjTypeOption = response.data.data
        }
      })
    },
    // 新零件弹窗
    openNewStockDialog() {
      if (this.dataForm.id) {
        this.showPart = false
      } else {
        this.showPart = true
      }
    },
    selectPart(part) {
      if (part) {
        this.dataForm.toPartId = part.id
        this.dataForm.toPartNo = part.partNo
        this.dataForm.toPartDesc = part.partName
        this.$refs.dataForm.validateField('toPartNo', (valid) => {})
      }
    },
    // 新库位弹窗
    openLocationDialog() {
      if (this.dataForm.id) {
        this.showLocation = false
      } else {
        this.showLocation = true
      }
    },
    selectLocation(location) {
      if (location) {
        this.dataForm.toLocId = location.id
        this.dataForm.toLoc = location.locNo
        this.$refs.dataForm.validateField('toLoc', (valid) => {})
      }
    },
    // 原零件库存弹窗
    openStockDialog() {
      if (this.dataForm.id) {
        this.showStock = false
      } else {
        this.showStock = true
      }
    },
    selectStock(stock) {
      if (stock) {
        this.dataForm.adjNum = stock.availableStockQuantity
        this.dataForm.fromPartNo = stock.partNo
        this.dataForm.formLoc = stock.locationNo
        this.dataForm.fromPartBatchNo = stock.partBatchNo
        this.dataForm.fromPartDesc = stock.partName
        this.dataForm.fromPartId = stock.partId
        this.dataForm.fromLocId = stock.locationId
        this.dataForm.systemNo = stock.systemNo
        this.$refs.dataForm.validateField('fromPartNo', (valid) => {})
      }
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
